<?php

/**
 * @file
 * Plugin to provide a content type for the paddle menu manager node menu items.
 */

/**
 * Plugin definition.
 */
$plugin = array(
  'title' => t('Node Menu Items'),
  'description' => t('Renders a list of menu items linking to a specific node.'),
  'category' => t('Paddle Menu Manager'),
  'required context' => new ctools_context_required(t('Node'), 'node'),
);

/**
 * Render callback.
 */
function paddle_menu_manager_node_menu_items_content_type_render($subtype, $conf, $args, $context) {
  ctools_include('ajax');
  ctools_include('modal');

  $block = new stdClass();
  $block->title = t('Navigation');
  $block->content = '';

  // Stop if no node has been set.
  if (empty($context->data) || empty($context->data->nid)) {
    return $block;
  }

  $block->content = ctools_modal_text_button(t('Add to menu'), 'admin/structure/menu_manager/nojs/node/' . $context->data->nid . '/add_menu_link', t('Create a menu link to this page.'), 'button add-button');

  $node = $context->data;

  $menu_links = paddle_menu_manager_get_menu_links_by_nid($node->nid);

  $items = array();

  foreach ($menu_links as $mlid => $menu_link) {
    $menu = menu_load($menu_link['menu_name']);
    $breadcrumb_titles = paddle_menu_manager_breadcrumb_titles($menu_link);
    $items[] = array(
      'data' => theme('paddle_menu_manager_node_menu_item', array(
        'menu_link' => $menu_link,
        'menu' => $menu,
        'breadcrumb' => $breadcrumb_titles,
        'node' => $node,
      )),
      'class' => array('mlid-' . $mlid),
    );
  }

  $variables = array(
    'items' => $items,
    'attributes' => array('class' => 'node-menu-links'),
  );
  $block->content .= theme('item_list', $variables);

  return $block;
}

/**
 * Settings form builder callback.
 */
function paddle_menu_manager_node_menu_items_content_type_edit_form($form, &$form_state) {
  return $form;
}

/**
 * Displays the administrative title for a panel pane in the drag & drop UI.
 */
function paddle_menu_manager_node_menu_items_content_type_admin_title($subtype, $conf, $context) {
  return t('Node Menu Items');
}
