<?php

/**
 * @file
 * Paddle Admin''s theme implementation to display a single Drupal page.
 *
 * The doctype, html, head and body tags are not in this template. Instead they
 * can be found in the html.tpl.php template normally located in the
 * modules/system directory.
 *
 * Available variables:
 *
 * General utility variables:
 * - $base_path: The base URL path of the Drupal installation. At the very
 *   least, this will always default to /.
 * - $directory: The directory the template is located in, e.g. modules/system
 *   or themes/bartik.
 * - $is_front: TRUE if the current page is the front page.
 * - $logged_in: TRUE if the user is registered and signed in.
 * - $is_admin: TRUE if the user has permission to access administration pages.
 *
 * Site identity:
 * - $front_page: The URL of the front page. Use this instead of $base_path,
 *   when linking to the front page. This includes the language domain or
 *   prefix.
 * - $logo: The path to the logo image, as defined in theme configuration.
 * - $site_name: The name of the site, empty when display has been disabled
 *   in theme settings.
 * - $site_slogan: The slogan of the site, empty when display has been disabled
 *   in theme settings.
 * - $hide_site_name: TRUE if the site name has been toggled off on the theme
 *   settings page. If hidden, the "element-invisible" class is added to make
 *   the site name visually hidden, but still accessible.
 * - $hide_site_slogan: TRUE if the site slogan has been toggled off on the
 *   theme settings page. If hidden, the "element-invisible" class is added to
 *   make the site slogan visually hidden, but still accessible.
 *
 * Navigation:
 * - $main_menu (array): An array containing the Main menu links for the
 *   site, if they have been configured.
 * - $secondary_menu (array): An array containing the Secondary menu links for
 *   the site, if they have been configured.
 * - $breadcrumb: The breadcrumb trail for the current page.
 *
 * Page content (in order of occurrence in the default page.tpl.php):
 * - $title_prefix (array): An array containing additional output populated by
 *   modules, intended to be displayed in front of the main title tag that
 *   appears in the template.
 * - $title: The page title, for use in the actual HTML content.
 * - $title_suffix (array): An array containing additional output populated by
 *   modules, intended to be displayed after the main title tag that appears in
 *   the template.
 * - $messages: HTML for status and error messages. Should be displayed
 *   prominently.
 * - $tabs (array): Tabs linking to any sub-pages beneath the current page
 *   (e.g., the view and edit tabs when displaying a node).
 * - $action_links (array): Actions local to the page, such as 'Add menu' on the
 *   menu administration interface.
 * - $feed_icons: A string of all feed icons for the current page.
 * - $node: The node object, if there is an automatically-loaded node
 *   associated with the page, and the node ID is the second argument
 *   in the page's path (e.g. node/12345 and node/12345/revisions, but not
 *   comment/reply/12345).
 *
 * Regions:
 * - $page['header']: Items for the header region.
 * - $page['featured']: Items for the featured region.
 * - $page['highlighted']: Items for the highlighted content region.
 * - $page['help']: Dynamic help text, mostly for admin pages.
 * - $page['content']: The main content of the current page.
 * - $page['sidebar_first']: Items for the first sidebar.
 * - $page['footer']: Items for the footer region.
 */
?>
<div id="page-wrapper">
  <div id="page">
    <div id="header_top">
        <div class="row">
          <div class="header-bar clearfix">
            <div id="toolbar">
              <div class="kanooh-logo-wrapper">
                <?php print $admin_home_logo_link;?>
                <div class="kanooh-logo"></div>
              </div>
              <?php if ($site_settings_menu): ?>
                <div class="site-settings-menu">
                  <?php print $site_settings_menu;?>
                </div>
              <?php endif; ?>
              <?php if ($toolbar_menu): ?>
                <div id="secondary-menu" class="navigation">
                  <?php print $toolbar_menu;?>
                </div>
              <?php endif; ?>
            </div><!-- /#toolbar -->
          </div>
        </div>
      </div>
    <div id="header">
      <div class="<?php print $secondary_menu ? 'with-secondary-menu' : 'without-secondary-menu'; ?>">
      <div class="container-fluid">
        <div class="menu-bg">
          <?php
            print render($page['header_top']);
          ?>
        </div>
      </div>
        <?php if($page['header_bottom']):/* first sidebar */?>
        <div id="header_bottom">
          <div class="max-width border">
            <?php print render($page['header_bottom']); ?>
          </div>
        </div>
        <?php endif; ?>
      </div>
    </div><!-- /#header -->
    <div id="main-wrapper" class="max-width clearfix">
      <div id="main" class="clearfix">
        <div id="main-content-wrapper">
          <div class="container-fluid">
            <div class="row">
              <?php if($page['sidebar_first']):/* first sidebar */?>
                <div id="background-empty"></div>
                <div id="sidebar_left">
                  <div class="full-height">
                    <?php print render($page['sidebar_first']); ?>
                  </div>
                </div>
              <?php endif; ?>
              <div id="content">
                <?php if ($messages): ?>
                  <div id="messages">
                    <?php print $messages; ?>
                  </div>
                  <!-- #messages-end -->
                <?php endif; ?>
                <div class="section">
                  <?php if ($page['highlighted']): ?>
                    <div id="highlighted">
                        <?php print render($page['highlighted']); ?>
                    </div>
                  <?php endif; ?>
                  <a id="main-content"></a>
                  <?php print render($title_prefix); ?>
                  <?php if ($title && $title_visible): ?>
                    <h1 class="title" id="page-title">
                      <?php print $title; ?>
                    </h1>
                  <?php endif; ?>
                  <?php print render($title_suffix); ?>
                  <?php if ($tabs): ?>
                    <div class="tabs">
                      <?php print render($tabs); ?>
                    </div>
                  <?php endif; ?>
                  <?php print render($page['help']); ?>
                  <?php if ($action_links): ?>
                    <ul class="action-links">
                      <?php print render($action_links); ?>
                    </ul>
                  <?php endif; ?>
                  <?php print render($page['content']); ?>
                  <?php print $feed_icons; ?>
                </div>
              </div> <!-- /.section, /#content -->
            <?php if($page['sidebar_second']): /* second sidebar */?>
              <div class="col-md-2">
                <?php print render($page['sidebar_second']); ?>
              </div>
            <?php endif; ?>
            </div>
          </div>
        </div><!-- /#main-content-wrapper -->
      </div>
    </div>
  </div>
</div> <!-- /#page, /#page-wrapper -->
